Module: Dynamic
- Extended by:
- ClassMethods
- Defined in:
- lib/dynamic.rb
Overview
This library was created by Christian Neukirchen in the context of EuRuKo 2005 and is licensed under the same terms as Ruby.
It provides dynamically scoped variables. It is used within
structured_warnings to store the current, thread-wide disabled warning
classes.
For more information see the corresponding slides at http://chneukirchen.org/talks/euruko-2005/chneukirchen-euruko2005-contextr.pdf and the blog post at http://chneukirchen.org/blog/archive/2005/04/dynamic-variables-in-ruby.html
(c) 2005 - Christian Neukirchen - http://chneukirchen.org
Defined Under Namespace
Modules: ClassMethods
Method Summary
Methods included from ClassMethods
[], []=, here!, let, main_dynamics, method_missing, undefine, variable, variables